<?php

//Set the content width based on the theme's design and stylesheet.
if ( ! isset( $content_width ) )
	$content_width = 1170; /* pixels */

/*-----------------------------------------------------------------------------------*/
/*  SETUP THEME
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'hakim_setup' ) ) :

	function hakim_setup() {
		// several theme support
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form' ) );	
		add_theme_support( 'html5', array( 'gallery', 'caption' ) );
		load_theme_textdomain( 'hakim', get_template_directory() .'/languages' );
		add_theme_support( "title-tag" );

}
endif;
add_action( 'after_setup_theme', 'hakim_setup' );

function hakim_thumbnail_setup() {
add_image_size( 'hakim-loop-post', 409, 250, true );
add_image_size( 'hakim-pagination-thumb', 9999, 180, true );
add_image_size( 'post-home', 500, 375, true );
add_image_size( 'practice-home', 367, 186, true );
add_image_size( 'hakim-about', 490, 260, true );
add_image_size( 'hakim-practice-area', 370, 255, true );
add_image_size( 'hakim-recentpost-thumb-widget', 60, 60, true );
}

add_action('after_setup_theme', 'hakim_thumbnail_setup');

/*-----------------------------------------------------------------------------------*/
/*  ACF
/*-----------------------------------------------------------------------------------*/

add_filter('acf/settings/show_admin', '__return_false');


/*-----------------------------------------------------------------------------------*/
/*  SCRIPTS & STYLES
/*-----------------------------------------------------------------------------------*/

function hakim_scripts() {

//All necessary CSS
wp_enqueue_style( 'bootstrap', get_template_directory_uri() .'/css/bootstrap.min.css', array(), null );
wp_enqueue_style( 'hakim-plugin-css', get_template_directory_uri() .'/css/plugin.css', array(), null );
wp_enqueue_style( 'hakim-responsive-css', get_template_directory_uri() .'/css/responsive.css', array(), null );
wp_enqueue_style( 'hakim-style', get_stylesheet_uri(), array( 'bootstrap','hakim-plugin-css' ) );
wp_enqueue_style( 'hakim-font', get_template_directory_uri() .'/css/font.css', array(), null );

//All Necessary Script
wp_enqueue_script( 'modernizr', get_template_directory_uri(). '/js/modernizr.js', array( 'jquery' ), '', false );
wp_enqueue_script( 'respond', get_template_directory_uri(). '/js/respond.js', array( 'jquery' ), '', false );
wp_enqueue_script( 'owlcarousel', get_template_directory_uri(). '/js/owl.carousel.min.js', array( 'jquery' ), '', true );
wp_enqueue_script( 'flexslider', get_template_directory_uri(). '/js/flexslider-min.js', array( 'jquery' ), '', true );
wp_enqueue_script( 'wow', get_template_directory_uri(). '/js/wow.js', array( 'jquery' ), '', true );
wp_enqueue_script( 'bootstrap', get_template_directory_uri(). '/js/bootstrap.min.js', array( 'jquery' ), '', true );
wp_enqueue_script( 'waypoints', get_template_directory_uri(). '/js/waypoints.js', array( 'jquery' ), '', true );
wp_enqueue_script( 'counterup', get_template_directory_uri(). '/js/counterup.js', array( 'jquery' ), '', true );
wp_enqueue_script( 'isotope', get_template_directory_uri(). '/js/isotope.js', array( 'jquery' ), '', true );
wp_enqueue_script( 'infinite-scroll', get_template_directory_uri(). '/js/infinite-scroll.js', array( 'jquery' ), '', true );
wp_enqueue_script( 'cond', get_template_directory_uri(). '/js/cond.js', array( 'jquery' ), '', true );
wp_enqueue_script( 'slitslider', get_template_directory_uri(). '/js/slitslider.js', array( 'jquery' ), '', true );
wp_enqueue_script( 'hakim-main-js', get_template_directory_uri(). '/js/main.js', array( 'jquery' ), '', true );
}

add_action( 'wp_enqueue_scripts', 'hakim_scripts' );

/*admin style*/
function hakim_admin_style() {
	wp_enqueue_style( 'hakim-admin-css', get_template_directory_uri() .'/css/admin.css', array(), null );
}
add_action('admin_head', 'hakim_admin_style');

add_action( 'wp_enqueue_scripts', 'hakim_comment_reply' );
function hakim_comment_reply(){
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
            wp_enqueue_script( 'comment-reply' );
    }
        
}

/*-----------------------------------------------------------------------------------*/
/*  CALL FRAMEWORK
/*-----------------------------------------------------------------------------------*/

require_once( get_template_directory() . '/inc/option/panel/config.php' );

/*-----------------------------------------------------------------------------------*/
/*  MENU
/*-----------------------------------------------------------------------------------*/

add_action( 'after_setup_theme', 'hakim_register_my_menu' );
function hakim_register_my_menu() {
	register_nav_menu( 'header-menu', esc_html__( 'Header Menu', 'hakim' ) );
}

//TOP MENU
function hakim_top_nav_menu(){
  wp_nav_menu( array(
	'theme_location' => 'header-menu',
	'container'       => 'ul',
   'menu_class'      => 'sm menus',
	'fallback_cb'  => 'hakim_header_menu_cb'
  ));
}

function hakim_top_mobile_menu(){
  wp_nav_menu( array(
	'theme_location' => 'header-menu',
	'container'       => 'ul',
   'menu_class'      => 'menus-mobile',
	'fallback_cb'  => 'hakim_header_menu_mobile_cb'
  ));
}

// FALLBACK IF PRIMARY MENU HAVEN'T SET YET
function hakim_header_menu_cb() {
  echo '<ul id="menu-top-menu" class="menus">';
  wp_list_pages('title_li=');
  echo '</ul>';
}

function hakim_header_menu_mobile_cb() {
  echo '<ul id="menu-top-mobile" class="menus-mobile">';
  wp_list_pages('title_li=');
  echo '</ul>';
}

/*-----------------------------------------------------------------------------------*/
/*  HEADER
/*-----------------------------------------------------------------------------------*/

// logo text or image huh?
function hakim_logo_type(){

$options = get_option('hakim_framework');
$logo = '';
if (isset($options['logo_upload'])) {
$logo = $options['logo_upload'];
$upload_logo = $logo['url'];
}


if ( ! empty( $upload_logo ) ) { ?>

	<div class="logo-image">
	<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url( $upload_logo ); ?>" class="image-logo" alt="<?php esc_attr_e( 'logo', 'hakim' ); ?>" /></a>
	</div>
	
	<?php } else { ?> 
	
	<div class="logo-title">
		<h2 class="site-title">
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a>
		</h2>
	</div>

<?php }
} 


/*-----------------------------------------------------------------------------------*/
/*  WIDGET
/*-----------------------------------------------------------------------------------*/


// SETUP DEFAULT SIDEBAR
function hakim_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Primary Sidebar', 'hakim' ),
		'id'            => 'primary-sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="heading-block"><h4>',
		'after_title'   => '</h4></div>',
	) );
}
add_action( 'widgets_init', 'hakim_widgets_init' );



/*-----------------------------------------------------------------------------------*/
/*  PAGINATION
/*-----------------------------------------------------------------------------------*/

function hakim_pagination($pages = '', $range = 2)
{  
		 $showitems = ($range * 2)+1;  

		 global $paged;
		 if(empty($paged)) $paged = 1;

		 if($pages == '')
		 {
				 global $wp_query;
				 $pages = $wp_query->max_num_pages;
				 if(!$pages)
				 {
						 $pages = 1;
				 }
		 }   

		 if(1 != $pages)
		 {
				 echo "<div class='pagination col-md-12 text-center'>";
				 if($paged > 2 && $paged > $range+1 && $showitems < $pages) echo "<a href='".get_pagenum_link(1)."'>First</a>";
				 if($paged > 1 && $showitems < $pages) echo "<a href='".get_pagenum_link($paged - 1)."'>&lsaquo;</a>";

				 for ($i=1; $i <= $pages; $i++)
				 {
						 if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
						 {
							echo (esc_html($paged) == esc_html($i))? "<span class='current'>".esc_html($i)."</span>":"<a href='".get_pagenum_link($i)."' class='inactive' >".esc_html($i)."</a>";
						 }
				 }

				 if ($paged < $pages && $showitems < $pages) echo "<a href='".get_pagenum_link($paged + 1)."'>&rsaquo;</a>";  
				 if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) echo "<a href='".get_pagenum_link($pages)."'>Last</a>";
				 echo "</div>\n";
		 }
}




/*-----------------------------------------------------------------------------------*/
/*  CUSTOM FUNCTIONS
/*-----------------------------------------------------------------------------------*/
require_once( get_template_directory() . '/inc/function/custom.php' );
require_once( get_template_directory() . '/inc/function/navigation.php' );
require_once( get_template_directory() . '/inc/function/aq_resizer.php' );
require_once( get_template_directory() . '/inc/function/comment.php' );
require_once( get_template_directory() . '/inc/function/akmanda-customizer.php' );
require_once( get_template_directory() . '/inc/function/meta-box.php' );
require_once( get_template_directory() . '/inc/function/thefooter.php' );

// INSTALL NECESSARY PLUGINS
require_once( get_template_directory() . '/class-tgm.php' ); /*activate plugin function*/
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327957&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        